SystemdDirs

Struct SystemdDirs 

pub struct SystemdDirs { /* private fields */ }
A struct to snapshot the environment at the time of creation.

The SystemdDirs methods return Path objects as immutable references to the paths as available when Self::new was called. This differs from the standalone functions, which return PathBuf objects.

Implementations

Source

impl SystemdDirs

pub fn new() -> Self

Returns a new SystemdDirs struct with a snapshot of the current environment.

Examples
use systemd_directories::SystemdDirs;
let dirs = SystemdDirs::new();
Examples found in repository?
examples/struct.rs (line 5)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dir());
7    println!("state dir: {:?}", dirs.state_dir());
8    println!("cache dir: {:?}", dirs.cache_dir());
9    println!("log dir: {:?}", dirs.logs_dir());
10    println!("config dir: {:?}", dirs.config_dir());
11}
More examples
Hide additional examples
examples/struct_multiple.rs (line 5)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dirs());
7    println!("state dir: {:?}", dirs.state_dirs());
8    println!("cache dir: {:?}", dirs.cache_dirs());
9    println!("log dir: {:?}", dirs.logs_dirs());
10    println!("config dir: {:?}", dirs.config_dirs());
11}
pub fn runtime_dirs(&self) -> Vec<&Path>

Returns all runtime directories as defined by RuntimeDirectory in the unit file.

If the environment variable RUNTIME_DIRECTORY was not set when SystemdDirs was created, it returns an empty vector. If it was set, it returns all paths in the colon-separated list. To get just the first path, use Self::runtime_dir.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let runtime_dirs = dirs.runtime_dirs();
Examples found in repository?
examples/struct_multiple.rs (line 6)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dirs());
7    println!("state dir: {:?}", dirs.state_dirs());
8    println!("cache dir: {:?}", dirs.cache_dirs());
9    println!("log dir: {:?}", dirs.logs_dirs());
10    println!("config dir: {:?}", dirs.config_dirs());
11}
pub fn runtime_dir(&self) -> Option<&Path>

Returns the first runtime directory as defined by RuntimeDirectory in the unit file.

If the environment variable RUNTIME_DIRECTORY was not set when SystemdDirs was created, it returns None. If it was set, it returns the first path in the colon-separated list. To get all paths, use Self::runtime_dirs.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let runtime_dir = dirs.runtime_dir();
Examples found in repository?
examples/struct.rs (line 6)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dir());
7    println!("state dir: {:?}", dirs.state_dir());
8    println!("cache dir: {:?}", dirs.cache_dir());
9    println!("log dir: {:?}", dirs.logs_dir());
10    println!("config dir: {:?}", dirs.config_dir());
11}
pub fn state_dirs(&self) -> Vec<&Path>

Returns all state directories as defined by StateDirectory in the unit file.

If the environment variable STATE_DIRECTORY was not set when SystemdDirs was created, it returns an empty vector. If it was set, it returns all paths in the colon-separated list. To get just the first path, use Self::state_dir.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let state_dirs = dirs.state_dirs();
Examples found in repository?
examples/struct_multiple.rs (line 7)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dirs());
7    println!("state dir: {:?}", dirs.state_dirs());
8    println!("cache dir: {:?}", dirs.cache_dirs());
9    println!("log dir: {:?}", dirs.logs_dirs());
10    println!("config dir: {:?}", dirs.config_dirs());
11}
pub fn state_dir(&self) -> Option<&Path>

Returns the first state directory as defined by StateDirectory in the unit file.

If the environment variable STATE_DIRECTORY was not set when SystemdDirs was created, it returns None. If it was set, it returns the first path in the colon-separated list. To get all paths, use Self::state_dirs.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let state_dir = dirs.state_dir();
Examples found in repository?
examples/struct.rs (line 7)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dir());
7    println!("state dir: {:?}", dirs.state_dir());
8    println!("cache dir: {:?}", dirs.cache_dir());
9    println!("log dir: {:?}", dirs.logs_dir());
10    println!("config dir: {:?}", dirs.config_dir());
11}
pub fn cache_dirs(&self) -> Vec<&Path>

Returns all cache directories as defined by CacheDirectory in the unit file.

If the environment variable CACHE_DIRECTORY was not set when SystemdDirs was created, it returns an empty vector. If it was set, it returns all paths in the colon-separated list. To get just the first path, use Self::cache_dir.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let cache_dirs = dirs.cache_dirs();
Examples found in repository?
examples/struct_multiple.rs (line 8)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dirs());
7    println!("state dir: {:?}", dirs.state_dirs());
8    println!("cache dir: {:?}", dirs.cache_dirs());
9    println!("log dir: {:?}", dirs.logs_dirs());
10    println!("config dir: {:?}", dirs.config_dirs());
11}
pub fn cache_dir(&self) -> Option<&Path>

Returns the first cache directory as defined by CacheDirectory in the unit file.

If the environment variable CACHE_DIRECTORY was not set when SystemdDirs was created, it returns None. If it was set, it returns the first path in the colon-separated list. To get all paths, use Self::cache_dirs.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let cache_dir = dirs.cache_dir();
Examples found in repository?
examples/struct.rs (line 8)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dir());
7    println!("state dir: {:?}", dirs.state_dir());
8    println!("cache dir: {:?}", dirs.cache_dir());
9    println!("log dir: {:?}", dirs.logs_dir());
10    println!("config dir: {:?}", dirs.config_dir());
11}
pub fn logs_dirs(&self) -> Vec<&Path>

Returns all logs directories as defined by LogsDirectory in the unit file.

If the environment variable LOGS_DIRECTORY was not set when SystemdDirs was created, it returns an empty vector. If it was set, it returns all paths in the colon-separated list. To get just the first path, use Self::logs_dir.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let logs_dirs = dirs.logs_dirs();
Examples found in repository?
examples/struct_multiple.rs (line 9)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dirs());
7    println!("state dir: {:?}", dirs.state_dirs());
8    println!("cache dir: {:?}", dirs.cache_dirs());
9    println!("log dir: {:?}", dirs.logs_dirs());
10    println!("config dir: {:?}", dirs.config_dirs());
11}
pub fn logs_dir(&self) -> Option<&Path>

Returns the first logs directory as defined by LogsDirectory in the unit file.

If the environment variable LOGS_DIRECTORY was not set when SystemdDirs was created, it returns None. If it was set, it returns the first path in the colon-separated list. To get all paths, use Self::logs_dirs.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let logs_dir = dirs.logs_dir();
Examples found in repository?
examples/struct.rs (line 9)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dir());
7    println!("state dir: {:?}", dirs.state_dir());
8    println!("cache dir: {:?}", dirs.cache_dir());
9    println!("log dir: {:?}", dirs.logs_dir());
10    println!("config dir: {:?}", dirs.config_dir());
11}
pub fn config_dirs(&self) -> Vec<&Path>

Returns all configuration directories as defined by ConfigurationDirectory in the unit file.

If the environment variable CONFIGURATION_DIRECTORY was not set when SystemdDirs was created, it returns an empty vector. If it was set, it returns all paths in the colon-separated list. To get just the first path, use Self::config_dir.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let config_dirs = dirs.config_dirs();
Examples found in repository?
examples/struct_multiple.rs (line 10)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dirs());
7    println!("state dir: {:?}", dirs.state_dirs());
8    println!("cache dir: {:?}", dirs.cache_dirs());
9    println!("log dir: {:?}", dirs.logs_dirs());
10    println!("config dir: {:?}", dirs.config_dirs());
11}
pub fn config_dir(&self) -> Option<&Path>

Returns the first configuration directory as defined by ConfigurationDirectory in the unit file.

If the environment variable CONFIGURATION_DIRECTORY was not set when SystemdDirs was created, it returns None. If it was set, it returns the first path in the colon-separated list. To get all paths, use Self::config_dirs.

Examples
let dirs = systemd_directories::SystemdDirs::new();
let config_dir = dirs.config_dir();
Examples found in repository?
examples/struct.rs (line 10)
3fn main() {
4    // NOTE: These will possibly be empty if not running under systemd
5    let dirs = SystemdDirs::new();
6    println!("runtime dir: {:?}", dirs.runtime_dir());
7    println!("state dir: {:?}", dirs.state_dir());
8    println!("cache dir: {:?}", dirs.cache_dir());
9    println!("log dir: {:?}", dirs.logs_dir());
10    println!("config dir: {:?}", dirs.config_dir());
11}